@@ -4,11 +4,11 @@ import os
 from logging import Logger, getLogger
 from pathlib import Path
 
-import dp
+import dp.configs
 from dp.utils.io import read_config
 
-main_dir = os.path.dirname(os.path.abspath(dp.__file__))
-config_file_path = Path(main_dir) / 'configs/logging.yaml'
+main_dir = os.path.dirname(os.path.abspath(dp.configs.__file__))
+config_file_path = Path(main_dir) / 'logging.yaml'
 config = read_config(config_file_path)
 logging.config.dictConfig(config)
 
